## ----styleSweave, eval=TRUE, echo=FALSE, results="asis"--------------------
BiocStyle::latex(use.unsrturl=FALSE)

## ----include=FALSE---------------------------------------------------------
library(knitr)
opts_chunk$set(
concordance=TRUE
)

## ----options, echo=FALSE---------------------------------------------------
options(prompt = " ", continue = " ")

## ----CranPck, eval=TRUE, echo=TRUE-----------------------------------------
Cran.pck<-c("scales", "reshape2", "plyr",
            "ggplot2", "ggrepel", "ggalluvial",
            "FactoMineR", "factoextra",
            "plot3D", "plot3Drgl",
            "UpSetR", "gprofiler2")

## ----installCranPck, eval=FALSE, echo=TRUE---------------------------------
#  Select.package.CRAN<-"FactoMineR"
#  #
#  if(!require(package=Select.package.CRAN,
#              quietly=TRUE, character.only=TRUE, warn.conflicts=FALSE)){
#    install.packages(pkgs=Select.package.CRAN, dependencies=TRUE)
#  }# if(!require(package=Cran.pck[i], quietly=TRUE, character.only=TRUE))

## ----BioconductorPck, eval=TRUE, echo=TRUE---------------------------------
Bioconductor.pck<-c("Mfuzz","SummarizedExperiment","DESeq2","ComplexHeatmap")

## ----BiocManagerPck, eval=FALSE, echo=TRUE---------------------------------
#  if(!require(package="BiocManager",
#              quietly=TRUE, character.only=TRUE, warn.conflicts=FALSE)){
#    install.packages("BiocManager")
#  }# if(!require(package="BiocManager", quietly=TRUE, character.only=TRUE))

## ----BiocconductorVersion, eval=FALSE, echo=TRUE---------------------------
#  BiocManager::install(version = "3.16")

## ----installBioconductorpck, eval=FALSE, echo=TRUE-------------------------
#  Select.package.CRAN<-"DESeq2"
#  if(!require(package=Select.package.CRAN,
#              quietly=TRUE, character.only=TRUE, warn.conflicts=FALSE)){
#    BiocManager::install(pkgs=Select.package.CRAN)
#  }# if(!require(package=Select.package.CRAN, quietly=TRUE, character.only=TRUE))

## ----library, eval=TRUE, echo=TRUE-----------------------------------------
library(MultiRNAflow)

## ----LoadMus1, echo=TRUE, eval=TRUE----------------------------------------
data("RawCounts_Antoszewski2022_MOUSEsub500")

## ----LoadFission, echo=TRUE, eval=TRUE-------------------------------------
data("RawCounts_Leong2014_FISSIONsub500wt")

## ----LoadLeuk, echo=TRUE, eval=TRUE----------------------------------------
data("RawCounts_Schleiss2021_CLLsub500")

## ----LoadMus2, echo=TRUE, eval=TRUE----------------------------------------
data("RawCounts_Weger2021_MOUSEsub500")

## ----ColnamesExample, echo=TRUE, eval=TRUE---------------------------------
data("RawCounts_Leong2014_FISSIONsub500wt")
colnames(RawCounts_Leong2014_FISSIONsub500wt)

## ----ExampleParametersData, echo=FALSE, eval=TRUE--------------------------
data("RawCounts_Leong2014_FISSIONsub500wt")

## ----ExampleParameters, echo=TRUE, eval=TRUE-------------------------------
resSEexample <- DATAprepSE(RawCounts=RawCounts_Leong2014_FISSIONsub500wt,
                           Column.gene=1,
                           Group.position=NULL,
                           Time.position=2,
                           Individual.position=3)

## ----DATAprepSEmus1, echo=TRUE, eval=TRUE----------------------------------
resSEmus1500 <- DATAprepSE(RawCounts=RawCounts_Antoszewski2022_MOUSEsub500,
                           Column.gene=1,
                           Group.position=1,
                           Time.position=NULL,
                           Individual.position=2)

## ----DATAprepSEfission, echo=TRUE, eval=TRUE-------------------------------
resSEfission500 <- DATAprepSE(RawCounts=RawCounts_Leong2014_FISSIONsub500wt,
                              Column.gene=1,
                              Group.position=NULL,
                              Time.position=2,
                              Individual.position=3)

## ----DATAprepSEleuk, eval=TRUE---------------------------------------------
resSEleuk500 <- DATAprepSE(RawCounts=RawCounts_Schleiss2021_CLLsub500,
                           Column.gene=1,
                           Group.position=2,
                           Time.position=4,
                           Individual.position=3)

## ----DATAprepSEmus22, eval=TRUE--------------------------------------------
resSEmus2500 <- DATAprepSE(RawCounts=RawCounts_Weger2021_MOUSEsub500,
                           Column.gene=1,
                           Group.position=1,
                           Time.position=2,
                           Individual.position=3)

## ----NormalizationMouse1, echo=TRUE, eval=TRUE-----------------------------
resNORMmus1500 <- DATAnormalization(SEres=resSEmus1500,
                                    Normalization="rle",
                                    Blind.rlog.vst=FALSE,
                                    Plot.Boxplot=TRUE,
                                    Colored.By.Factors=TRUE,
                                    Color.Group=NULL,
                                    path.result=NULL)

## ----NormalizationMouseColor, eval=TRUE------------------------------------
data.col.mus50<-data.frame(Name=c("N1wtT1wt","N1haT1wt","N1haT1ko","N1wtT1ko"),
                           Col=c("black","red","green","blue"))

## ----NormalizationFission, eval=TRUE---------------------------------------
resNORMyeast500 <- DATAnormalization(SEres=resSEfission500,
                                     Normalization="rlog",
                                     Blind.rlog.vst=FALSE,
                                     Plot.Boxplot=FALSE,
                                     Colored.By.Factors=TRUE,
                                     Color.Group=NULL,
                                     Plot.genes=FALSE,
                                     path.result=NULL)

## ----NormalizationLeukemia, eval=TRUE--------------------------------------
resNORMleuk500<-DATAnormalization(SEres=resSEleuk500,
                                  Normalization="vst",
                                  Blind.rlog.vst=FALSE,
                                  Plot.Boxplot=FALSE,
                                  Colored.By.Factors=TRUE,
                                  Color.Group = NULL,
                                  path.result=NULL)

## ----NormalizationCLLcolor, eval=TRUE--------------------------------------
data.col.Leuk<-data.frame(Name=c("NP","P"),
                          Col=c("black","red"))

## ----NormalizationMouse2, eval=TRUE----------------------------------------
resNORMmus2500 <- DATAnormalization(SEres=resSEmus2500,
                                    Normalization="vst",
                                    Blind.rlog.vst=FALSE,
                                    Plot.Boxplot=FALSE,
                                    Colored.By.Factors=TRUE,
                                    Color.Group=NULL,
                                    path.result=NULL)

## ----NormalizationMus2color, eval=TRUE-------------------------------------
data.col.Mus2 <- data.frame(Name=c("BmKo","BmWt","CrKo","CrWt"),
                            Col=c("red","blue","orange","darkgreen"))

## ----PCAMouse1, eval=TRUE--------------------------------------------------
ResPCAMus500 <- PCAanalysis(SEresNorm=resNORMmus1500,
                            sample.deletion=NULL,
                            Supp.del.sample=FALSE,
                            gene.deletion=NULL,
                            Plot.PCA=TRUE,
                            Mean.Accross.Time=FALSE,
                            Color.Group = NULL,
                            Cex.label=0.8,
                            Cex.point=0.7, epsilon=0.2,
                            Phi=25,Theta=140,
                            D3.mouvement=FALSE,
                            path.result=NULL)

## ----PCAMouseColor, eval=TRUE----------------------------------------------
data.col.mus50<-data.frame(Name=c("N1wtT1wt","N1haT1wt","N1haT1ko","N1wtT1ko"),
                           Col=c("black","red","green","blue"))
data.col.mus50

## ----HCPCmouse1, warning=FALSE, message=FALSE, eval=TRUE-------------------
ResHCPCMus500 <- HCPCanalysis(SEresNorm=resNORMmus1500,
                              gene.deletion=NULL,
                              sample.deletion=NULL,
                              Supp.del.sample=FALSE,
                              Plot.HCPC=FALSE,
                              Cex.label=0.8, Cex.point=0.7, epsilon=0.2,
                              Phi=25, Theta=140,
                              D3.mouvement=FALSE,
                              path.result=NULL)

## ----PCAfission, warning=FALSE, message=FALSE, eval=TRUE-------------------
ResPCAYeast500 <- PCAanalysis(SEresNorm=resNORMyeast500,
                              gene.deletion=NULL,
                              sample.deletion=NULL,
                              Supp.del.sample=FALSE,
                              Plot.PCA=FALSE,
                              Mean.Accross.Time=FALSE,
                              Cex.label=0.8, Cex.point=0.7, epsilon=0.3,
                              Phi=25,Theta=140,
                              D3.mouvement=FALSE,
                              path.result=NULL)

## ----HCPCfission, warning=FALSE, message=FALSE, eval=TRUE------------------
ResHCPCYeast500 <- HCPCanalysis(SEresNorm=resNORMyeast500,
                                gene.deletion=NULL,
                                sample.deletion=NULL,
                                Supp.del.sample=FALSE,
                                Plot.HCPC=TRUE,
                                Cex.label=0.9,
                                Cex.point=0.7,
                                epsilon=0.2,
                                Phi=25,Theta=140,
                                D3.mouvement=FALSE,
                                path.result=NULL)

## ----PCALeukemia, warning=FALSE, message=FALSE, eval=TRUE------------------
ResPCALeuk500 <- PCAanalysis(SEresNorm=resNORMleuk500,
                             gene.deletion=NULL,
                             sample.deletion=NULL,
                             Supp.del.sample=FALSE,
                             Plot.PCA=FALSE,
                             Mean.Accross.Time=FALSE,
                             Color.Group = NULL,
                             Cex.label=0.9,
                             Cex.point=0.8,epsilon=0.2,
                             Phi=25,Theta=140,
                             D3.mouvement=FALSE,
                             path.result=NULL,
                             Name.folder.pca=NULL)

## ----PCAleukColor, warning=FALSE, message=FALSE, eval=TRUE-----------------
data.col.Leuk<-data.frame(Name=c("NP","P"),
                          Col=c("black","red"))

## ----HCPCleukemia, warning=FALSE, message=FALSE, eval=TRUE-----------------
ResHCPCLeuk500 <- HCPCanalysis(SEresNorm=resNORMleuk500,
                               gene.deletion=NULL,
                               sample.deletion=NULL,
                               Supp.del.sample=FALSE,
                               Plot.HCPC=FALSE,
                               Phi=25,Theta=140,
                               Cex.point=0.7,
                               epsilon=0.2,
                               Cex.label=0.9,
                               D3.mouvement=FALSE,
                               path.result=NULL,
                               Name.folder.hcpc=NULL)

## ----PCAMus2, warning=FALSE, message=FALSE, eval=TRUE----------------------
ResPCAMus2500 <- PCAanalysis(SEresNorm=resNORMmus2500,
                             gene.deletion=NULL,
                             sample.deletion=NULL,
                             Supp.del.sample=FALSE,
                             Plot.PCA=FALSE,
                             Mean.Accross.Time=FALSE,
                             Color.Group=NULL,
                             Cex.label=0.6,
                             Cex.point=0.7, epsilon=0.2,
                             Phi=25,Theta=140,
                             D3.mouvement=FALSE,
                             path.result=NULL,
                             Name.folder.pca=NULL)

## ----PCAmus2color, warning=FALSE, message=FALSE, eval=TRUE-----------------
data.col.Mus2<-data.frame(Name=c("BmKo","BmWt","CrKo","CrWt"),
                          Col=c("red","blue","orange","darkgreen"))

## ----HCPCmus2500, warning=FALSE, message=FALSE, eval=TRUE------------------
ResHCPCMus2500 <- HCPCanalysis(SEresNorm=resNORMmus2500,
                               gene.deletion=NULL,
                               sample.deletion=NULL,
                               Supp.del.sample=FALSE,
                               Plot.HCPC=FALSE,
                               Phi=25,Theta=140,
                               Cex.point=0.6,
                               epsilon=0.2,
                               Cex.label=0.6,
                               D3.mouvement=FALSE,
                               path.result=NULL,
                               Name.folder.hcpc=NULL)

## ----MfuzzFission, warning=FALSE, message=FALSE, eval=TRUE-----------------
ResMfuzzYeast500 <- MFUZZanalysis(SEresNorm=resNORMyeast500,
                                  DataNumberCluster=NULL,
                                  Method="hcpc",
                                  Membership=0.5,
                                  Min.std=0.1,
                                  Plot.Mfuzz=TRUE,
                                  path.result=NULL)

## ----MfuzzLeuk, warning=FALSE, message=FALSE, eval=TRUE--------------------
ResMfuzzLeuk500 <- MFUZZanalysis(SEresNorm = resNORMleuk500,
                                 DataNumberCluster=NULL,
                                 Method="hcpc",
                                 Membership=0.7,
                                 Min.std=0.1,
                                 Plot.Mfuzz=FALSE,
                                 path.result=NULL,
                                 Name.folder.mfuzz=NULL)

## ----MfuzzMus2, warning=FALSE, message=FALSE, eval=TRUE--------------------
ResMfuzzLeuk500 <- MFUZZanalysis(SEresNorm=resNORMmus2500,
                                 DataNumberCluster=NULL,
                                 Method="hcpc",
                                 Membership=0.5,
                                 Min.std=0.1,
                                 Plot.Mfuzz=FALSE,
                                 path.result=NULL, Name.folder.mfuzz=NULL)

## ----DATAplotExpressionGenesMouse, warning=FALSE, message=FALSE, eval=TRUE----
resEVOmus1500 <- DATAplotExpressionGenes(SEresNorm=resNORMmus1500,
                                         Vector.row.gene=c(10),
                                         Color.Group=NULL,
                                         Plot.Expression=TRUE,
                                         path.result=NULL)

## ----ProfileMouseColor, warning=FALSE, message=FALSE, eval=TRUE------------
data.col.mus50<-data.frame(Name=c("N1wtT1wt","N1haT1wt","N1haT1ko","N1wtT1ko"),
                           Col=c("black","red","green","blue"))

## ----DATAplotExpressionGenesFission, warning=FALSE, message=FALSE, eval=TRUE----
resEVOyeast500<-DATAplotExpressionGenes(SEresNorm=resNORMyeast500,
                                        Vector.row.gene=c(17),
                                        Plot.Expression=TRUE,
                                        path.result=NULL)

## ----DATAplotExpressionGenesLeukemia, warning=FALSE, message=FALSE, eval=TRUE----
resEVOleuk500 <- DATAplotExpressionGenes(SEresNorm=resNORMleuk500,
                                         Vector.row.gene=c(25),
                                         Color.Group = NULL,
                                         Plot.Expression=FALSE,
                                         path.result=NULL,
                                         Name.folder.profile=NULL)

## ----ProfileCLLcolor, warning=FALSE, message=FALSE, eval=TRUE--------------
data.col.Leuk<-data.frame(Name=c("NP","P"),
                          Col=c("black","red"))

## ----DATAplotExpressionGenesMusBmCrKoWt, warning=FALSE, message=FALSE, eval=TRUE----
resEVOmus2500 <- DATAplotExpressionGenes(SEresNorm=resNORMmus2500,
                                         Vector.row.gene=c(17),
                                         Color.Group=NULL,
                                         Plot.Expression=FALSE,
                                         path.result=NULL)

## ----PreprocessPCAHcpcMusBmCrKoWt, warning=FALSE, message=FALSE, eval=TRUE----
data.col.MusBmCrKoWt<-data.frame(Name=c("BmKo","BmWt","CrKo","CrWt"),
                                Col=c("black","blue","green","red"))

## ----DEmouse, warning=FALSE, message=FALSE, eval=TRUE----------------------
ResDEMus500 <- DEanalysisGlobal(SEres=resSEmus1500,
                                pval.min=0.05,
                                pval.vect.t=NULL,
                                log.FC.min=1,
                                LRT.supp.info=FALSE,
                                Plot.DE.graph=TRUE,
                                path.result=NULL,
                                Name.folder.DE=NULL)
# data("Results_DEanalysis_sub500")
# ResDEMus500<-Results_DEanalysis_sub500$DE_Antoszewski2022_MOUSEsub500

## ----DEresultsMouse1, warning=FALSE, message=FALSE, eval=TRUE--------------
Res.DE.results.Mus1 <- SummarizedExperiment::rowData(ResDEMus500)

## ----GlossaryMouse1, warning=FALSE, message=FALSE, eval=TRUE---------------
ResGlossary.Mus1 <- S4Vectors::metadata(ResDEMus500)$DESeq2obj$List.Glossary

## ----DEanalysisFISSION, warning=FALSE, message=FALSE, eval=TRUE------------
# DEyeast500wt <- DEanalysisGlobal(SEres=resSEfission500,
#                                  pval.min=0.05,
#                                  pval.vect.t=NULL,
#                                  log.FC.min=1,
#                                  LRT.supp.info=FALSE,
#                                  Plot.DE.graph =FALSE,
#                                  path.result=NULL,
#                                  Name.folder.DE=NULL)
data("Results_DEanalysis_sub500")
DEyeast500wt <- Results_DEanalysis_sub500$DE_Leong2014_FISSIONsub500wt

## ----DEresultsFission, warning=FALSE, message=FALSE, eval=TRUE-------------
Res.DE.results.Fission <- SummarizedExperiment::rowData(DEyeast500wt)

## ----GlossaryFission, warning=FALSE, message=FALSE, eval=TRUE--------------
ResGlossary.Fission <- S4Vectors::metadata(DEyeast500wt)$DESeq2obj$List.Glossary

## ----DELeuk, warning=FALSE, message=FALSE, eval=TRUE-----------------------
ResDELeuk500 <- DEanalysisGlobal(SEres=resSEleuk500,
                                 pval.min=0.05,
                                 pval.vect.t=NULL,
                                 log.FC.min=1,
                                 LRT.supp.info=FALSE,
                                 Plot.DE.graph =TRUE,
                                 path.result=NULL,
                                 Name.folder.DE=NULL)

# data("Results_DEanalysis_sub500")
# ResDELeuk500<-Results_DEanalysis_sub500$DE_Schleiss2021_CLLsub500

## ----DEresultsLeukemia, warning=FALSE, message=FALSE, eval=TRUE------------
Res.DE.results.Leuk <- SummarizedExperiment::rowData(ResDELeuk500)

## ----GlossaryLeukemia, warning=FALSE, message=FALSE, eval=TRUE-------------
ResGlossary.Leuk <- S4Vectors::metadata(ResDELeuk500)$DESeq2obj$List.Glossary

## ----UsbMusBmCrKoWt, warning=FALSE, message=FALSE, eval=TRUE---------------
Sub3bc3T <- RawCounts_Weger2021_MOUSEsub500[, seq_len(73)]
SelectTime <- grep("_t0_", colnames(Sub3bc3T))
SelectTime <- c(SelectTime, grep("_t1_", colnames(Sub3bc3T)))
SelectTime <- c(SelectTime, grep("_t2_", colnames(Sub3bc3T)))
Sub3bc3T <- Sub3bc3T[, c(1, SelectTime)]

resSEmus25003b3t <- DATAprepSE(RawCounts=Sub3bc3T,
                               Column.gene=1,
                               Group.position=1,
                               Time.position=2,
                               Individual.position=3)

## ----DEMusBmCrKoWt, warning=FALSE, message=FALSE, eval=TRUE----------------
ResDEMusBmCrKoWt500<-DEanalysisGlobal(SEres=resSEmus25003b3t,
                                      pval.min=0.05,
                                      pval.vect.t=NULL,
                                      log.FC.min=1,
                                      LRT.supp.info=FALSE,
                                      Plot.DE.graph=FALSE,
                                      path.result=NULL, Name.folder.DE=NULL)

## ----VolcanoMAMus1, warning=FALSE, message=FALSE, eval=TRUE----------------
resVolcanoMAMouse <- DEplotVolcanoMA(SEresDE=ResDEMus500,
                                     NbGene.plotted=2,
                                     SizeLabel=3,
                                     Display.plots=TRUE,
                                     Save.plots=FALSE)

## ----HeatmapsMus1, warning=FALSE, message=FALSE, eval=TRUE-----------------
resplotHeatmapMus <- DEplotHeatmaps(SEresDE=ResDEMus500,
                                    ColumnsCriteria=2,#c(2,4),
                                    Set.Operation="union",
                                    NbGene.analysis=20,
                                    SizeLabelRows=5,
                                    SizeLabelCols=5,
                                    Display.plots=TRUE,
                                    Save.plots=FALSE)

## ----VolcanoMA_FISSION, warning=FALSE, message=FALSE, eval=TRUE------------
resVolcanoMAFission <- DEplotVolcanoMA(SEresDE=DEyeast500wt,
                                       NbGene.plotted=2,
                                       SizeLabel=3,
                                       Display.plots=TRUE,
                                       Save.plots=TRUE)

## ----Heatmaps_FISSION, warning=FALSE, message=FALSE, eval=TRUE-------------
resplotHeatmapFission <- DEplotHeatmaps(SEresDE=DEyeast500wt,
                                        ColumnsCriteria=2,
                                        Set.Operation="union",
                                        NbGene.analysis=20,
                                        Color.Group=NULL,
                                        SizeLabelRows=5,
                                        SizeLabelCols=5,
                                        Display.plots=TRUE,
                                        Save.plots=FALSE)

## ----VolcanoMA_CLL, warning=FALSE, message=FALSE, eval=TRUE----------------
resVolcanoMACLL<-DEplotVolcanoMA(SEresDE=ResDELeuk500,
                                 NbGene.plotted=2,
                                 SizeLabel=3,
                                 Display.plots=FALSE,
                                 Save.plots=FALSE)

## ----Heatmaps_CCL, warning=FALSE, message=FALSE, eval=TRUE-----------------
resplotHeatmapCLL<-DEplotHeatmaps(SEresDE=ResDELeuk500,
                                  ColumnsCriteria=c(12, 13),
                                  Set.Operation="union",
                                  NbGene.analysis=20,
                                  SizeLabelRows=5,
                                  SizeLabelCols=5,
                                  Display.plots=FALSE,
                                  Save.plots=FALSE)

## ----VolcanoMA_Mouse2, warning=FALSE, message=FALSE, eval=TRUE-------------
resVolcanoMAMouse2<-DEplotVolcanoMA(SEresDE=ResDEMusBmCrKoWt500,
                                    NbGene.plotted=2,
                                    SizeLabel=3,
                                    Display.plots=FALSE,
                                    Save.plots=FALSE)

## ----Heatmaps_Mouse2, warning=FALSE, message=FALSE, eval=TRUE--------------
resplotHeatmapMouse2<-DEplotHeatmaps(SEresDE=ResDEMusBmCrKoWt500,
                                     ColumnsCriteria=2:5,
                                     Set.Operation="union",
                                     NbGene.analysis=20,
                                     SizeLabelRows=5,
                                     SizeLabelCols=5,
                                     Display.plots=FALSE,
                                     Save.plots=FALSE)

## ----GSEAquickAnalysis_Mus, warning=FALSE, message=FALSE, eval=TRUE--------
resGSEAgprofiler2Mus<-GSEAQuickAnalysis(Internect.Connection=FALSE,
                                        SEresDE=ResDEMus500,
                                        ColumnsCriteria=2,
                                        ColumnsLog2ordered=NULL,
                                        Set.Operation="union",
                                        Organism="mmusculus",
                                        MaxNumberGO=10,
                                        Background=FALSE,
                                        Display.plots=FALSE,
                                        Save.plots=FALSE)
#
# head(4Vectors::metadata(resGSEAgprofiler2Mus)$Rgprofiler2$GSEAresults)

## ----GSEAprepro_Mus1, warning=FALSE, message=FALSE, eval=TRUE--------------
resGSEApreprocessingFission<-GSEApreprocessing(SEresDE=ResDEMus500,
                                               ColumnsCriteria=2,
                                               Set.Operation="union",
                                               Rnk.files=FALSE,
                                               Save.files=FALSE)

## ----GSEAquickAnalysis_Fission, warning=FALSE, message=FALSE, eval=TRUE----
resGSEAgprofiler2Fission<-GSEAQuickAnalysis(Internect.Connection=FALSE,
                                            SEresDE=DEyeast500wt,
                                            ColumnsCriteria=2,
                                            ColumnsLog2ordered=NULL,
                                            Set.Operation="union",
                                            Organism="spombe",
                                            MaxNumberGO=20,
                                            Background=FALSE,
                                            Display.plots=FALSE,
                                            Save.plots=FALSE)
#
# head(resGSEAgprofiler2Fission$GSEAresults)

## ----GSEAprepro_Fission, warning=FALSE, message=FALSE, eval=TRUE-----------
resGSEApreprocessingFission<-GSEApreprocessing(SEresDE=DEyeast500wt,
                                               ColumnsCriteria=2,
                                               Set.Operation="union",
                                               Rnk.files=FALSE,
                                               Save.files=FALSE)

## ----GSEAquickAnalysis_CLL, warning=FALSE, message=FALSE, eval=TRUE--------
resGSEAgprofiler2Leuk<-GSEAQuickAnalysis(Internect.Connection=FALSE,
                                         SEresDE=ResDELeuk500,
                                         ColumnsCriteria=c(12,13),
                                         ColumnsLog2ordered=NULL,
                                         Set.Operation="union",
                                         Organism="hsapiens",
                                         MaxNumberGO=20,
                                         Background=FALSE,
                                         Display.plots=FALSE,
                                         Save.plots=FALSE)
#
# head(resGSEAgprofiler2Leuk$GSEAresults)

## ----GSEAprepro_CLL, warning=FALSE, message=FALSE, eval=TRUE---------------
resGSEApreprocessingLeuk<-GSEApreprocessing(SEresDE=ResDELeuk500,
                                            ColumnsCriteria=c(12,13),
                                            Set.Operation="union",
                                            Rnk.files=FALSE,
                                            Save.files=FALSE)

## ----GSEAquickAnalysis_Mouse2, warning=FALSE, message=FALSE, eval=TRUE-----
resGSEAgprofiler2Mouse2<-GSEAQuickAnalysis(Internect.Connection=FALSE,
                                           SEresDE=ResDEMusBmCrKoWt500,
                                           ColumnsCriteria=2:5,
                                           ColumnsLog2ordered=NULL,
                                           Set.Operation="union",
                                           Organism="mmusculus",
                                           MaxNumberGO=20,
                                           Background=FALSE,
                                           Display.plots=FALSE,
                                           Save.plots=FALSE)
#
# head(resGSEAgprofiler2Mouse2$GSEAresults)

## ----GSEAprepro_Mouse2, warning=FALSE, message=FALSE, eval=TRUE------------
resGSEApreprocessing<-GSEApreprocessing(SEresDE=ResDEMusBmCrKoWt500,
                                        ColumnsCriteria=2:5,
                                        Set.Operation="union",
                                        Rnk.files=FALSE,
                                        Save.files=TRUE)

## ----sessionInfo, echo=FALSE, results="asis"-------------------------------
utils::toLatex(sessionInfo())

